@@ -279,6 +279,14 @@ class SyntaxAnalyzer(BaseAnalyzer):
             try:
                 property_value = object_property.parser.parse(property_value)
             except ValueParserError as error:
+                self._logger.error(
+                    f"Error while parsing {property_value} for {object_property.key}, falling back to default"
+                )
+                # First, fallback to the default value for the property, then re-raise
+                property_value = self._format_property_value(
+                    object_property.default_value, object_property
+                )
+                setattr(ast_object, object_property_name, property_value)
                 raise SyntaxAnalyzerError(
                     ast_object, object_property, error.error_message, error
                 )
