@@ -83,7 +83,7 @@ class ODLLicenseMetadata(Node):
             raise ValueError("Argument 'formats' must be a list")
         if created and not isinstance(created, datetime.datetime):
             raise ValueError(
-                "Argument 'created' must be an instance of {}".format(datetime.datetime)
+                f"Argument 'created' must be an instance of {datetime.datetime}"
             )
 
         self.identifier = identifier
